@@ -8,6 +8,7 @@ from sk_transformers.generic_transformer import (
     AggregateTransformer,
     AllowedValuesTransformer,
     ColumnDropperTransformer,
+    ColumnEvalTransformer,
     DtypeTransformer,
     FunctionsTransformer,
     LeftJoinTransformer,
@@ -24,4 +25,5 @@ from sk_transformers.string_transformer import (
     PhoneTransformer,
     StringSimilarityTransformer,
     StringSlicerTransformer,
+    StringSplitterTransformer,
 )
