@@ -12,9 +12,12 @@ from sk_transformers.utils import check_ready_to_transform
 
 
 class ToVecTransformer(BaseEstimator, TransformerMixin):
-    """
-    This transformer trains an [FT-Transformer](https://paperswithcode.com/method/ft-transformer)
-    using the [pytorch-widedeep package](https://github.com/jrzaurin/pytorch-widedeep) and extracts the embeddings
+    """This transformer trains an [FT-
+    Transformer](https://paperswithcode.com/method/ft-transformer) using the.
+
+    [pytorch-widedeep package](https://github.com/jrzaurin/pytorch-widedeep)
+    and extracts the embeddings.
+
     from its embedding layer. The output shape of the transformer is (number of rows,(`input_dim` * number of columns)).
     Please refer to [this example](https://pytorch-widedeep.readthedocs.io/en/latest/examples/09_extracting_embeddings.html)
     for pytorch_widedeep example on how to extract embeddings.
@@ -24,7 +27,7 @@ class ToVecTransformer(BaseEstimator, TransformerMixin):
     import numpy as np
     import pandas as pd
     from pytorch_widedeep.datasets import load_adult
-    from sk_transformers.deep_transformer import ToVecTransformer
+    from sk_transformers import ToVecTransformer
 
     df = load_adult(as_frame=True)
     df["target"] = (df["income"].apply(lambda x: ">50K" in x)).astype(int)
@@ -99,8 +102,8 @@ class ToVecTransformer(BaseEstimator, TransformerMixin):
         self.tab_vec_: Optional[Tab2Vec] = None
 
     def fit(self, X: pd.DataFrame, y: NDArray) -> "ToVecTransformer":
-        """
-        Fits the `ToVecTransformer`. The `TabPreprocessor` is fitted and the `FTTransformer` is trained.
+        """Fits the `ToVecTransformer`. The `TabPreprocessor` is fitted and the
+        `FTTransformer` is trained.
 
         Args:
             X (pd.DataFrame): The input data.
@@ -151,8 +154,8 @@ class ToVecTransformer(BaseEstimator, TransformerMixin):
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Transforms the input data and returns the embeddings.
+        """Transforms the input data and returns the embeddings.
+
         The output shape is (number of rows,(`input_dim` * number of columns)).
 
         Args:
@@ -165,6 +168,6 @@ class ToVecTransformer(BaseEstimator, TransformerMixin):
         X = check_ready_to_transform(
             self,
             X,
-            self.cat_embed_columns + self.continuous_columns,
+            list(self.cat_embed_columns) + list(self.continuous_columns),
         )
         return self.tab_vec_.transform(X)  # type: ignore
